DialogWidget class

Displays Material dialog above the current contents of the app

Inheritance

Constructors

DialogWidget({Key? key, String? title, String? msg, List<Widget>? actions, LottieBuilder? animationBuilder, Widget customView = const SizedBox(), CustomViewPosition customViewPosition = CustomViewPosition.BEFORE_TITLE, TextStyle? titleStyle, TextStyle? msgStyle, TextAlign? titleAlign, TextAlign? msgAlign, double? dialogWidth, Color? color})

Properties

actions → List<Widget>?
actionsWidgets to display a row of buttons after the msg widget.
final
animationBuilder → LottieBuilder?
animationBuilder lottie animations builder
final
color → Color?
color dialog's backgorund color
final
customView → Widget
customView a widget to display a custom widget instead of the animation view.
final
customViewPosition → CustomViewPosition
final
dialogWidth → double?
dialogWidth dialog's width compared to the screen width
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
msg → String?
msg your dialog description message
final
msgAlign → TextAlign?
textAlign dialog description text alignment
final
msgStyle → TextStyle?
animation lottie animations path
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String?
title your dialog title
final
titleAlign → TextAlign?
titleAlign dialog title text alignment
final
titleStyle → TextStyle?
titleStyle dialog title text style
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
buttons(BuildContext context) → Widget
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited